@@ -6,10 +6,9 @@ from datetime import datetime
 from os import getenv
 from pathlib import Path
 from sys import exit, stderr
-from time import sleep as time_sleep
 from typing import List, Optional
 
-import vlc
+from ymplayer import Player
 
 from exclock.util import (
     DEFAULT_RING_FILENAME,
@@ -64,10 +63,8 @@ def main(opt: optparse.Values, args: List[str]) -> None:
         message = f"Specified time is passed(sec={spend_sec})."
         notify_all(title="⏰ Exclock ⏰", message=message, spend_sec=spend_sec, is_first=False)
 
-        p = vlc.MediaPlayer(ring_sound_filename)
+        p = Player(ring_sound_filename)
         p.play()
-        while p.get_state() != vlc.State.Ended:
-            time_sleep(0.2)
     except KeyboardInterrupt:
         ...
     finally:
